#!/usr/bin/env python

import time, torch

if torch.cuda.is_available():
    device = torch.device('cuda')
    sync = lambda: torch.cuda.synchronize()
else:
    device = torch.device('cpu')
    sync = lambda: None

nb_runs = 10000
d1, d2, d3 = 2048, 2048, 2048

a, b = torch.rand(d1, d2).to(device), torch.rand(d2, d3).to(device)

sync
start_time = time.perf_counter()
for k in range(nb_runs):
    c = a @ b
sync
duration = time.perf_counter() - start_time

nb_flop = float(nb_runs * d1 * d2 * d3 * 2) # 1 multiply-and-add is 2 ops
speed = nb_flop / duration

for u in [ '', 'K', 'M', 'G', 'T', 'P' ]:
    if speed < 1e3: break
    speed /= 1e3

print(f'{speed:.02f} {u}flops on {device}')

